import { QueryClient } from '@kevisual/query';
import { modal } from './redirect-to-login';
import { create } from 'zustand';
import { message } from './message';
import { QueryLogin } from '@kevisual/query-login';

export const query = new QueryClient();

/**
 * 登录查询
 */
export const queryLogin = new QueryLogin({
  query,
});
// @ts-ignore
if (window.context) {
  // @ts-ignore
  window.context.queryLogin = queryLogin;
} else {
  // @ts-ignore
  window.context = {
    queryLogin,
  };
}
// 在请求之前，如果stop了
query.beforeRequest = async (config) => {
  if (config.headers) {
    const token = localStorage.getItem('token');
    if (token) {
      config.headers['Authorization'] = 'Bearer ' + token;
    }
  }
  return config;
};
query.afterResponse = async (res, ctx) => {
  if (res?.code === 401) {
    if (query?.stop) {
      return { code: 500, success: false, message: '登录已过期' };
    }
    query.stop = true;
    const queryLoginRes = await queryLogin.afterCheck401ToRefreshToken(res, ctx);
    query.stop = false;
    if (queryLoginRes.code === 401) {
      modal.setOpen(true);
    }
    return queryLoginRes;
  }

  return res as any;
};
export const request = query.post;

export const ws = query.qws?.ws || new WebSocket(query.qws?.url);
type Store = {
  connected: boolean;
  setConnected: (connected: boolean) => void;
};
export const useStore = create<Store>((set) => ({
  connected: false,
  setConnected: (connected) => set({ connected }),
}));

// 当连接成功时
ws.onopen = () => {
  console.log('Connected to WebSocket server');
  useStore.getState().setConnected(true);
};

// 处理 WebSocket 关闭
ws.onclose = () => {
  console.log('Disconnected from WebSocket server');
};
